"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .address import Address, AddressTypedDict
from .checkoutstatus import CheckoutStatus
from .polar_enums_paymentprocessor import PolarEnumsPaymentProcessor
from .product import Product, ProductInput, ProductInputTypedDict, ProductTypedDict
from .productprice import ProductPrice, ProductPriceTypedDict
from datetime import datetime
from polar_sdk.types import BaseModel, Nullable, UNSET_SENTINEL
from polar_sdk.utils import validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import Dict
from typing_extensions import Annotated, TypedDict


class PaymentProcessorMetadataTypedDict(TypedDict):
    pass


class PaymentProcessorMetadata(BaseModel):
    pass


class PolarCheckoutSchemasCheckoutTypedDict(TypedDict):
    r"""Checkout session data retrieved using an access token."""

    created_at: datetime
    r"""Creation timestamp of the object."""
    modified_at: Nullable[datetime]
    r"""Last modification timestamp of the object."""
    id: str
    r"""The ID of the object."""
    status: CheckoutStatus
    client_secret: str
    r"""Client secret used to update and complete the checkout session from the client."""
    url: str
    r"""URL where the customer can access the checkout session."""
    expires_at: datetime
    r"""Expiration date and time of the checkout session."""
    success_url: str
    r"""URL where the customer will be redirected after a successful payment."""
    embed_origin: Nullable[str]
    r"""When checkout is embedded, represents the Origin of the page embedding the checkout. Used as a security measure to send messages only to the embedding page."""
    amount: Nullable[int]
    tax_amount: Nullable[int]
    r"""Computed tax amount to pay in cents."""
    currency: Nullable[str]
    r"""Currency code of the checkout session."""
    total_amount: Nullable[int]
    r"""Total amount to pay in cents."""
    product_id: str
    r"""ID of the product to checkout."""
    product_price_id: str
    r"""ID of the product price to checkout."""
    is_payment_required: bool
    r"""Whether the checkout requires payment. Useful to detect free products."""
    customer_id: Nullable[str]
    customer_name: Nullable[str]
    customer_email: Nullable[str]
    customer_ip_address: Nullable[str]
    customer_billing_address: Nullable[AddressTypedDict]
    customer_tax_id: Nullable[str]
    payment_processor_metadata: PaymentProcessorMetadataTypedDict
    metadata: Dict[str, str]
    product: ProductTypedDict
    r"""A product."""
    product_price: ProductPriceTypedDict
    subscription_id: Nullable[str]
    payment_processor: PolarEnumsPaymentProcessor


class PolarCheckoutSchemasCheckout(BaseModel):
    r"""Checkout session data retrieved using an access token."""

    created_at: datetime
    r"""Creation timestamp of the object."""

    modified_at: Nullable[datetime]
    r"""Last modification timestamp of the object."""

    id: str
    r"""The ID of the object."""

    status: CheckoutStatus

    client_secret: str
    r"""Client secret used to update and complete the checkout session from the client."""

    url: str
    r"""URL where the customer can access the checkout session."""

    expires_at: datetime
    r"""Expiration date and time of the checkout session."""

    success_url: str
    r"""URL where the customer will be redirected after a successful payment."""

    embed_origin: Nullable[str]
    r"""When checkout is embedded, represents the Origin of the page embedding the checkout. Used as a security measure to send messages only to the embedding page."""

    amount: Nullable[int]

    tax_amount: Nullable[int]
    r"""Computed tax amount to pay in cents."""

    currency: Nullable[str]
    r"""Currency code of the checkout session."""

    total_amount: Nullable[int]
    r"""Total amount to pay in cents."""

    product_id: str
    r"""ID of the product to checkout."""

    product_price_id: str
    r"""ID of the product price to checkout."""

    is_payment_required: bool
    r"""Whether the checkout requires payment. Useful to detect free products."""

    customer_id: Nullable[str]

    customer_name: Nullable[str]

    customer_email: Nullable[str]

    customer_ip_address: Nullable[str]

    customer_billing_address: Nullable[Address]

    customer_tax_id: Nullable[str]

    payment_processor_metadata: PaymentProcessorMetadata

    metadata: Dict[str, str]

    product: Product
    r"""A product."""

    product_price: ProductPrice

    subscription_id: Nullable[str]

    PAYMENT_PROCESSOR: Annotated[
        Annotated[
            PolarEnumsPaymentProcessor,
            AfterValidator(validate_const(PolarEnumsPaymentProcessor.STRIPE)),
        ],
        pydantic.Field(alias="payment_processor"),
    ] = PolarEnumsPaymentProcessor.STRIPE

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = []
        nullable_fields = [
            "modified_at",
            "embed_origin",
            "amount",
            "tax_amount",
            "currency",
            "total_amount",
            "customer_id",
            "customer_name",
            "customer_email",
            "customer_ip_address",
            "customer_billing_address",
            "customer_tax_id",
            "subscription_id",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class PolarCheckoutSchemasCheckoutInputTypedDict(TypedDict):
    r"""Checkout session data retrieved using an access token."""

    created_at: datetime
    r"""Creation timestamp of the object."""
    modified_at: Nullable[datetime]
    r"""Last modification timestamp of the object."""
    id: str
    r"""The ID of the object."""
    status: CheckoutStatus
    client_secret: str
    r"""Client secret used to update and complete the checkout session from the client."""
    url: str
    r"""URL where the customer can access the checkout session."""
    expires_at: datetime
    r"""Expiration date and time of the checkout session."""
    success_url: str
    r"""URL where the customer will be redirected after a successful payment."""
    embed_origin: Nullable[str]
    r"""When checkout is embedded, represents the Origin of the page embedding the checkout. Used as a security measure to send messages only to the embedding page."""
    amount: Nullable[int]
    tax_amount: Nullable[int]
    r"""Computed tax amount to pay in cents."""
    currency: Nullable[str]
    r"""Currency code of the checkout session."""
    total_amount: Nullable[int]
    r"""Total amount to pay in cents."""
    product_id: str
    r"""ID of the product to checkout."""
    product_price_id: str
    r"""ID of the product price to checkout."""
    is_payment_required: bool
    r"""Whether the checkout requires payment. Useful to detect free products."""
    customer_id: Nullable[str]
    customer_name: Nullable[str]
    customer_email: Nullable[str]
    customer_ip_address: Nullable[str]
    customer_billing_address: Nullable[AddressTypedDict]
    customer_tax_id: Nullable[str]
    payment_processor_metadata: PaymentProcessorMetadataTypedDict
    metadata: Dict[str, str]
    product: ProductInputTypedDict
    r"""A product."""
    product_price: ProductPriceTypedDict
    subscription_id: Nullable[str]
    payment_processor: PolarEnumsPaymentProcessor


class PolarCheckoutSchemasCheckoutInput(BaseModel):
    r"""Checkout session data retrieved using an access token."""

    created_at: datetime
    r"""Creation timestamp of the object."""

    modified_at: Nullable[datetime]
    r"""Last modification timestamp of the object."""

    id: str
    r"""The ID of the object."""

    status: CheckoutStatus

    client_secret: str
    r"""Client secret used to update and complete the checkout session from the client."""

    url: str
    r"""URL where the customer can access the checkout session."""

    expires_at: datetime
    r"""Expiration date and time of the checkout session."""

    success_url: str
    r"""URL where the customer will be redirected after a successful payment."""

    embed_origin: Nullable[str]
    r"""When checkout is embedded, represents the Origin of the page embedding the checkout. Used as a security measure to send messages only to the embedding page."""

    amount: Nullable[int]

    tax_amount: Nullable[int]
    r"""Computed tax amount to pay in cents."""

    currency: Nullable[str]
    r"""Currency code of the checkout session."""

    total_amount: Nullable[int]
    r"""Total amount to pay in cents."""

    product_id: str
    r"""ID of the product to checkout."""

    product_price_id: str
    r"""ID of the product price to checkout."""

    is_payment_required: bool
    r"""Whether the checkout requires payment. Useful to detect free products."""

    customer_id: Nullable[str]

    customer_name: Nullable[str]

    customer_email: Nullable[str]

    customer_ip_address: Nullable[str]

    customer_billing_address: Nullable[Address]

    customer_tax_id: Nullable[str]

    payment_processor_metadata: PaymentProcessorMetadata

    metadata: Dict[str, str]

    product: ProductInput
    r"""A product."""

    product_price: ProductPrice

    subscription_id: Nullable[str]

    PAYMENT_PROCESSOR: Annotated[
        Annotated[
            PolarEnumsPaymentProcessor,
            AfterValidator(validate_const(PolarEnumsPaymentProcessor.STRIPE)),
        ],
        pydantic.Field(alias="payment_processor"),
    ] = PolarEnumsPaymentProcessor.STRIPE

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = []
        nullable_fields = [
            "modified_at",
            "embed_origin",
            "amount",
            "tax_amount",
            "currency",
            "total_amount",
            "customer_id",
            "customer_name",
            "customer_email",
            "customer_ip_address",
            "customer_billing_address",
            "customer_tax_id",
            "subscription_id",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .productpriceonetime import ProductPriceOneTime, ProductPriceOneTimeTypedDict
from .productpricerecurring import ProductPriceRecurring, ProductPriceRecurringTypedDict
from typing import Union


ProductPriceTypedDict = Union[
    ProductPriceRecurringTypedDict, ProductPriceOneTimeTypedDict
]


ProductPrice = Union[ProductPriceRecurring, ProductPriceOneTime]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .donation import Donation, DonationTypedDict
from enum import Enum
from polar_sdk.types import BaseModel
from polar_sdk.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing_extensions import Annotated, TypedDict


class WebhookDonationCreatedPayloadType(str, Enum):
    DONATION_CREATED = "donation.created"


class WebhookDonationCreatedPayloadTypedDict(TypedDict):
    r"""Sent when a new donation is created.

    **Discord & Slack support:** Full
    """

    data: DonationTypedDict
    type: WebhookDonationCreatedPayloadType


class WebhookDonationCreatedPayload(BaseModel):
    r"""Sent when a new donation is created.

    **Discord & Slack support:** Full
    """

    data: Donation

    TYPE: Annotated[
        Annotated[
            WebhookDonationCreatedPayloadType,
            AfterValidator(
                validate_const(WebhookDonationCreatedPayloadType.DONATION_CREATED)
            ),
        ],
        pydantic.Field(alias="type"),
    ] = WebhookDonationCreatedPayloadType.DONATION_CREATED



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .product import Product, ProductTypedDict
from .productprice import ProductPrice, ProductPriceTypedDict
from polar_sdk.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from pydantic import model_serializer
from typing_extensions import NotRequired, TypedDict


class PolarCheckoutLegacySchemasCheckoutTypedDict(TypedDict):
    r"""A checkout session."""

    id: str
    r"""The ID of the checkout."""
    customer_email: Nullable[str]
    customer_name: Nullable[str]
    product: ProductTypedDict
    r"""A product."""
    product_price: ProductPriceTypedDict
    url: NotRequired[Nullable[str]]
    r"""URL the customer should be redirected to complete the purchase."""


class PolarCheckoutLegacySchemasCheckout(BaseModel):
    r"""A checkout session."""

    id: str
    r"""The ID of the checkout."""

    customer_email: Nullable[str]

    customer_name: Nullable[str]

    product: Product
    r"""A product."""

    product_price: ProductPrice

    url: OptionalNullable[str] = UNSET
    r"""URL the customer should be redirected to complete the purchase."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["url"]
        nullable_fields = ["customer_email", "customer_name", "url"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .product import ProductInput, ProductInputTypedDict
from enum import Enum
from polar_sdk.types import BaseModel
from polar_sdk.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing_extensions import Annotated, TypedDict


class WebhookProductUpdatedPayloadType(str, Enum):
    PRODUCT_UPDATED = "product.updated"


class WebhookProductUpdatedPayloadTypedDict(TypedDict):
    r"""Sent when a product is updated.

    **Discord & Slack support:** Basic
    """

    data: ProductInputTypedDict
    r"""A product."""
    type: WebhookProductUpdatedPayloadType


class WebhookProductUpdatedPayload(BaseModel):
    r"""Sent when a product is updated.

    **Discord & Slack support:** Basic
    """

    data: ProductInput
    r"""A product."""

    TYPE: Annotated[
        Annotated[
            WebhookProductUpdatedPayloadType,
            AfterValidator(
                validate_const(WebhookProductUpdatedPayloadType.PRODUCT_UPDATED)
            ),
        ],
        pydantic.Field(alias="type"),
    ] = WebhookProductUpdatedPayloadType.PRODUCT_UPDATED



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .product import Product, ProductTypedDict
from .productpricerecurring import ProductPriceRecurring, ProductPriceRecurringTypedDict
from .subscriptionrecurringinterval import SubscriptionRecurringInterval
from .subscriptionstatus import SubscriptionStatus
from .subscriptionuser import SubscriptionUser, SubscriptionUserTypedDict
from datetime import datetime
from polar_sdk.types import BaseModel, Nullable, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Dict
from typing_extensions import TypedDict


class SubscriptionTypedDict(TypedDict):
    created_at: datetime
    r"""Creation timestamp of the object."""
    modified_at: Nullable[datetime]
    r"""Last modification timestamp of the object."""
    id: str
    r"""The ID of the object."""
    amount: Nullable[int]
    currency: Nullable[str]
    recurring_interval: SubscriptionRecurringInterval
    status: SubscriptionStatus
    current_period_start: datetime
    current_period_end: Nullable[datetime]
    cancel_at_period_end: bool
    started_at: Nullable[datetime]
    ended_at: Nullable[datetime]
    user_id: str
    product_id: str
    price_id: str
    checkout_id: Nullable[str]
    metadata: Dict[str, str]
    user: SubscriptionUserTypedDict
    product: ProductTypedDict
    r"""A product."""
    price: ProductPriceRecurringTypedDict


class Subscription(BaseModel):
    created_at: datetime
    r"""Creation timestamp of the object."""

    modified_at: Nullable[datetime]
    r"""Last modification timestamp of the object."""

    id: str
    r"""The ID of the object."""

    amount: Nullable[int]

    currency: Nullable[str]

    recurring_interval: SubscriptionRecurringInterval

    status: SubscriptionStatus

    current_period_start: datetime

    current_period_end: Nullable[datetime]

    cancel_at_period_end: bool

    started_at: Nullable[datetime]

    ended_at: Nullable[datetime]

    user_id: str

    product_id: str

    price_id: str

    checkout_id: Nullable[str]

    metadata: Dict[str, str]

    user: SubscriptionUser

    product: Product
    r"""A product."""

    price: ProductPriceRecurring

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = []
        nullable_fields = [
            "modified_at",
            "amount",
            "currency",
            "current_period_end",
            "started_at",
            "ended_at",
            "checkout_id",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .subscription_input import SubscriptionInput, SubscriptionInputTypedDict
from enum import Enum
from polar_sdk.types import BaseModel
from polar_sdk.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing_extensions import Annotated, TypedDict


class WebhookSubscriptionRevokedPayloadType(str, Enum):
    SUBSCRIPTION_REVOKED = "subscription.revoked"


class WebhookSubscriptionRevokedPayloadTypedDict(TypedDict):
    r"""Sent when a subscription is revoked, the user looses access immediately.
    Happens when the subscription is canceled, or payment is past due.

    **Discord & Slack support:** Full
    """

    data: SubscriptionInputTypedDict
    type: WebhookSubscriptionRevokedPayloadType


class WebhookSubscriptionRevokedPayload(BaseModel):
    r"""Sent when a subscription is revoked, the user looses access immediately.
    Happens when the subscription is canceled, or payment is past due.

    **Discord & Slack support:** Full
    """

    data: SubscriptionInput

    TYPE: Annotated[
        Annotated[
            WebhookSubscriptionRevokedPayloadType,
            AfterValidator(
                validate_const(
                    WebhookSubscriptionRevokedPayloadType.SUBSCRIPTION_REVOKED
                )
            ),
        ],
        pydantic.Field(alias="type"),
    ] = WebhookSubscriptionRevokedPayloadType.SUBSCRIPTION_REVOKED



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .platforms import Platforms
from polar_sdk.types import BaseModel
from polar_sdk.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing_extensions import Annotated, TypedDict


class DonationOrganizationTypedDict(TypedDict):
    id: str
    name: str
    avatar_url: str
    is_personal: bool
    platform: Platforms


class DonationOrganization(BaseModel):
    id: str

    name: str

    avatar_url: str

    is_personal: bool

    PLATFORM: Annotated[
        Annotated[Platforms, AfterValidator(validate_const(Platforms.GITHUB))],
        pydantic.Field(alias="platform"),
    ] = Platforms.GITHUB



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
from polar_sdk import utils
from polar_sdk.types import BaseModel
from polar_sdk.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing_extensions import Annotated


class NotPermittedType(str, Enum):
    NOT_PERMITTED = "NotPermitted"


class NotPermittedData(BaseModel):
    detail: str

    TYPE: Annotated[
        Annotated[
            NotPermittedType,
            AfterValidator(validate_const(NotPermittedType.NOT_PERMITTED)),
        ],
        pydantic.Field(alias="type"),
    ] = NotPermittedType.NOT_PERMITTED


class NotPermitted(Exception):
    data: NotPermittedData

    def __init__(self, data: NotPermittedData):
        self.data = data

    def __str__(self) -> str:
        return utils.marshal_json(self.data, NotPermittedData)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from polar_sdk.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Dict
from typing_extensions import NotRequired, TypedDict


class CheckoutLinkUpdateTypedDict(TypedDict):
    r"""Schema to update an existing checkout link."""

    metadata: NotRequired[Nullable[Dict[str, str]]]
    r"""Key-value object allowing you to store additional information.

    The key must be a string with a maximum length of **40 characters**.
    The value must be a string with a maximum length of **500 characters**.
    You can store up to **50 key-value pairs**.
    """
    success_url: NotRequired[Nullable[str]]
    r"""URL where the customer will be redirected after a successful payment.You can add the `checkout_id={CHECKOUT_ID}` query parameter to retrieve the checkout session id."""


class CheckoutLinkUpdate(BaseModel):
    r"""Schema to update an existing checkout link."""

    metadata: OptionalNullable[Dict[str, str]] = UNSET
    r"""Key-value object allowing you to store additional information.

    The key must be a string with a maximum length of **40 characters**.
    The value must be a string with a maximum length of **500 characters**.
    You can store up to **50 key-value pairs**.
    """

    success_url: OptionalNullable[str] = UNSET
    r"""URL where the customer will be redirected after a successful payment.You can add the `checkout_id={CHECKOUT_ID}` query parameter to retrieve the checkout session id."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["metadata", "success_url"]
        nullable_fields = ["metadata", "success_url"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .orderbillingreason import OrderBillingReason
from .orderproduct import OrderProduct, OrderProductTypedDict
from .ordersubscription import OrderSubscription, OrderSubscriptionTypedDict
from .orderuser import OrderUser, OrderUserTypedDict
from .productprice import ProductPrice, ProductPriceTypedDict
from datetime import datetime
from polar_sdk.types import BaseModel, Nullable, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Dict
from typing_extensions import TypedDict


class OrderTypedDict(TypedDict):
    created_at: datetime
    r"""Creation timestamp of the object."""
    modified_at: Nullable[datetime]
    r"""Last modification timestamp of the object."""
    id: str
    r"""The ID of the object."""
    metadata: Dict[str, str]
    amount: int
    tax_amount: int
    currency: str
    billing_reason: OrderBillingReason
    user_id: str
    product_id: str
    product_price_id: str
    subscription_id: Nullable[str]
    checkout_id: Nullable[str]
    user: OrderUserTypedDict
    product: OrderProductTypedDict
    product_price: ProductPriceTypedDict
    subscription: Nullable[OrderSubscriptionTypedDict]


class Order(BaseModel):
    created_at: datetime
    r"""Creation timestamp of the object."""

    modified_at: Nullable[datetime]
    r"""Last modification timestamp of the object."""

    id: str
    r"""The ID of the object."""

    metadata: Dict[str, str]

    amount: int

    tax_amount: int

    currency: str

    billing_reason: OrderBillingReason

    user_id: str

    product_id: str

    product_price_id: str

    subscription_id: Nullable[str]

    checkout_id: Nullable[str]

    user: OrderUser

    product: OrderProduct

    product_price: ProductPrice

    subscription: Nullable[OrderSubscription]

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = []
        nullable_fields = [
            "modified_at",
            "subscription_id",
            "checkout_id",
            "subscription",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from polar_sdk.types import BaseModel
from typing_extensions import TypedDict


class BenefitLicenseKeyActivationPropertiesTypedDict(TypedDict):
    limit: int
    enable_user_admin: bool


class BenefitLicenseKeyActivationProperties(BaseModel):
    limit: int

    enable_user_admin: bool



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
from polar_sdk import utils
from polar_sdk.types import BaseModel
from polar_sdk.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing_extensions import Annotated


class FileNotFoundType(str, Enum):
    FILE_NOT_FOUND = "FileNotFound"


class FileNotFoundData(BaseModel):
    detail: str

    TYPE: Annotated[
        Annotated[
            FileNotFoundType,
            AfterValidator(validate_const(FileNotFoundType.FILE_NOT_FOUND)),
        ],
        pydantic.Field(alias="type"),
    ] = FileNotFoundType.FILE_NOT_FOUND


class FileNotFound(Exception):
    data: FileNotFoundData

    def __init__(self, data: FileNotFoundData):
        self.data = data

    def __str__(self) -> str:
        return utils.marshal_json(self.data, FileNotFoundData)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .polar_enums_paymentprocessor import PolarEnumsPaymentProcessor
from .productprice import ProductPrice, ProductPriceTypedDict
from datetime import datetime
from polar_sdk.types import BaseModel, Nullable, UNSET_SENTINEL
from polar_sdk.utils import validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import Dict
from typing_extensions import Annotated, TypedDict


class CheckoutLinkTypedDict(TypedDict):
    r"""Checkout link data."""

    created_at: datetime
    r"""Creation timestamp of the object."""
    modified_at: Nullable[datetime]
    r"""Last modification timestamp of the object."""
    id: str
    r"""The ID of the object."""
    metadata: Dict[str, str]
    client_secret: str
    r"""Client secret used to access the checkout link."""
    success_url: Nullable[str]
    r"""URL where the customer will be redirected after a successful payment."""
    product_price_id: str
    r"""ID of the product price to checkout."""
    product_price: ProductPriceTypedDict
    url: str
    payment_processor: PolarEnumsPaymentProcessor


class CheckoutLink(BaseModel):
    r"""Checkout link data."""

    created_at: datetime
    r"""Creation timestamp of the object."""

    modified_at: Nullable[datetime]
    r"""Last modification timestamp of the object."""

    id: str
    r"""The ID of the object."""

    metadata: Dict[str, str]

    client_secret: str
    r"""Client secret used to access the checkout link."""

    success_url: Nullable[str]
    r"""URL where the customer will be redirected after a successful payment."""

    product_price_id: str
    r"""ID of the product price to checkout."""

    product_price: ProductPrice

    url: str

    PAYMENT_PROCESSOR: Annotated[
        Annotated[
            PolarEnumsPaymentProcessor,
            AfterValidator(validate_const(PolarEnumsPaymentProcessor.STRIPE)),
        ],
        pydantic.Field(alias="payment_processor"),
    ] = PolarEnumsPaymentProcessor.STRIPE

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = []
        nullable_fields = ["modified_at", "success_url"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .pagination import Pagination, PaginationTypedDict
from .polar_checkout_schemas_checkout import (
    PolarCheckoutSchemasCheckout,
    PolarCheckoutSchemasCheckoutTypedDict,
)
from polar_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class ListResourceCheckoutTypedDict(TypedDict):
    items: List[PolarCheckoutSchemasCheckoutTypedDict]
    pagination: PaginationTypedDict


class ListResourceCheckout(BaseModel):
    items: List[PolarCheckoutSchemasCheckout]

    pagination: Pagination



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .productpricerecurringcustom import (
    ProductPriceRecurringCustom,
    ProductPriceRecurringCustomTypedDict,
)
from .productpricerecurringfixed import (
    ProductPriceRecurringFixed,
    ProductPriceRecurringFixedTypedDict,
)
from .productpricerecurringfree import (
    ProductPriceRecurringFree,
    ProductPriceRecurringFreeTypedDict,
)
from typing import Union


ProductPriceRecurringTypedDict = Union[
    ProductPriceRecurringFreeTypedDict,
    ProductPriceRecurringFixedTypedDict,
    ProductPriceRecurringCustomTypedDict,
]


ProductPriceRecurring = Union[
    ProductPriceRecurringFree, ProductPriceRecurringFixed, ProductPriceRecurringCustom
]
